pm4py.algo.merging.case\_relations.variants package
===================================================

Submodules
----------

pm4py.algo.merging.case\_relations.variants.pandas module
---------------------------------------------------------

.. automodule:: pm4py.algo.merging.case_relations.variants.pandas
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.merging.case_relations.variants
   :members:
   :undoc-members:
   :show-inheritance:
